@@ -1031,6 +1031,7 @@ static const char  *static_camera_list[] =
 "Canon PowerShot G6",
 "Canon PowerShot G7 (CHDK hack)",
 "Canon PowerShot G9",
+"Canon PowerShot G10",
 "Canon PowerShot S2 IS (CHDK hack)",
 "Canon PowerShot S3 IS (CHDK hack)",
 "Canon PowerShot S5 IS (CHDK hack)",
@@ -1045,6 +1046,7 @@ static const char  *static_camera_list[] =
 "Canon EOS D30",
 "Canon EOS D60",
 "Canon EOS 5D",
+"Canon EOS 5D Mark II",
 "Canon EOS 10D",
 "Canon EOS 20D",
 "Canon EOS 30D",
@@ -1145,6 +1147,7 @@ static const char  *static_camera_list[] =
 "Kodak KAI-0340",
 "Konica KD-400Z",
 "Konica KD-510Z",
+"Leaf AFi 7",
 "Leaf Aptus 17",
 "Leaf Aptus 22",
 "Leaf Aptus 54S",
@@ -1164,6 +1167,7 @@ static const char  *static_camera_list[] =
 "Leica Digilux 3",
 "Leica D-LUX2",
 "Leica D-LUX3",
+"Leica D-LUX4",
 "Leica V-LUX1",
 "Logitech Fotoman Pixtura",
 "Mamiya ZD",
@@ -1257,6 +1261,8 @@ static const char  *static_camera_list[] =
 "Panasonic DMC-FZ28",
 "Panasonic DMC-FZ30",
 "Panasonic DMC-FZ50",
+"Panasonic DMC-FX150",
+"Panasonic DMC-G1",
 "Panasonic DMC-L1",
 "Panasonic DMC-L10",
 "Panasonic DMC-LC1",
